==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_FindReplaceData.h <==
//----------------------------------------------------------------------------
// wxFindReplaceData
// extracted from fdrepdlg.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_FINDREPLACEDATA_H__
#define __CLASS_WX_FINDREPLACEDATA_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxFindReplaceData
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_FindReplaceData);

//----------------------------------------------------------------------------
// Object declaration for wxFindReplaceData
//----------------------------------------------------------------------------
class Object_wx_FindReplaceData : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_FindReplaceData)
public:
	inline Object_wx_FindReplaceData(wxFindReplaceData *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_FindReplaceData), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_FindReplaceData(Class *pClass, wxFindReplaceData *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_FindReplaceData();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxFindReplaceData *GetEntity() {
		return dynamic_cast<wxFindReplaceData *>(_pEntity);
	}
	inline wxFindReplaceData *ReleaseEntity() {
		wxFindReplaceData *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxFindReplaceData");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_FindReplaceData.h <==
//----------------------------------------------------------------------------
// wxFindReplaceData
// extracted from fdrepdlg.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_FINDREPLACEDATA_H__
#define __CLASS_WX_FINDREPLACEDATA_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxFindReplaceData
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_FindReplaceData);

//----------------------------------------------------------------------------
// Object declaration for wxFindReplaceData
//----------------------------------------------------------------------------
class Object_wx_FindReplaceData : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_FindReplaceData)
public:
	inline Object_wx_FindReplaceData(wxFindReplaceData *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_FindReplaceData), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_FindReplaceData(Class *pClass, wxFindReplaceData *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_FindReplaceData();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxFindReplaceData *GetEntity() {
		return dynamic_cast<wxFindReplaceData *>(_pEntity);
	}
	inline wxFindReplaceData *ReleaseEntity() {
		wxFindReplaceData *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxFindReplaceData");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
